var Utils = require('utils');
var Pokkt = require('pokkt_native_extension');

var vs = null;
var rewardedAdShowRequested = false;

function AdDemoScreen() {
	this.currentAdConfig = null;
	
	this.labelScreenName = null;
	this.labelPointsEarned = null;
	this.labelStatus = null;
	
	this.buttonCacheRewardedAd = null;
	this.buttonShowRewardedAd = null;
	this.buttonCacheNonRewardedAd = null;
	this.buttonShowNonRewardedAd = null;
	this.buttonExportLog = null;
	
	this.totalPointsEarned = 0.0;
	
	vs = this;
}

AdDemoScreen.prototype.createWindow = function (adConfig) {
	this.currentAdConfig = adConfig;
	
	// create root window
	this.rootWindow = Titanium.UI.createWindow({
		title:'Video-Ads Campaign Screen',
		backgroundColor:'#37bc9b'
	});
	
	this.labelScreenName = Utils.createLabel(adConfig.screenName, 100);
	this.rootWindow.add(this.labelScreenName);
	
	this.labelPointsEarned = Utils.createLabel('Points Earned: 0', 130);
	this.rootWindow.add(this.labelPointsEarned);
	
	this.labelStatus = Utils.createLabel('<perform an operation...>', 160);
	this.rootWindow.add(this.labelStatus);
	
	// cache rewarded ad button
	this.buttonCacheRewardedAd = Utils.createButton('Cache Rewarded Ad', 200, '#4a89dc', function (e){
        vs.buttonCacheRewardedAd.title = 'rewarded ad is downloading...';
        vs.buttonCacheRewardedAd.touchEnabled = false;
        vs.buttonShowRewardedAd.title = 'rewarded ad is downloading...';
        vs.buttonShowRewardedAd.touchEnabled = false;
        
		vs.currentAdConfig.isRewarded = true;
		Pokkt.cacheAd(vs.currentAdConfig);
	});
	this.rootWindow.add(this.buttonCacheRewardedAd);
	
	// cache non-rewarded ad button
	this.buttonCacheNonRewardedAd = Utils.createButton('Cache Non-Rewarded Ad', 260, '#967adc', function (e){
        vs.buttonCacheNonRewardedAd.title = 'non-rewarded ad is downloading...';
        vs.buttonCacheNonRewardedAd.touchEnabled = false;
        vs.buttonShowNonRewardedAd.title = 'non-rewarded ad is downloading...';
        vs.buttonShowNonRewardedAd.touchEnabled = false;

		vs.currentAdConfig.isRewarded = false;
		Pokkt.cacheAd(vs.currentAdConfig);
	});
	this.rootWindow.add(this.buttonCacheNonRewardedAd);
	
	// show rewarded ad button
	this.buttonShowRewardedAd = Utils.createButton('Show Rewarded Ad', 320, '#4a89dc', function (e){
		vs.currentAdConfig.isRewarded = true;
		Pokkt.showAd(vs.currentAdConfig);
	});
	this.rootWindow.add(this.buttonShowRewardedAd);
	
	// show non-rewarded ad button
	this.buttonShowNonRewardedAd = Utils.createButton('Show Non-Rewarded Ad', 380, '#967adc', function (e){
		vs.currentAdConfig.isRewarded = false;
		Pokkt.showAd(vs.currentAdConfig);
	});
	this.rootWindow.add(this.buttonShowNonRewardedAd);

	// export-log button
	this.rootWindow.add(Utils.createButton('Export Logs', 440, '#4a89dc', function(e){
		Titanium.API.info('exporting logs...');
		Pokkt.exportLog();
	}));
	
	this.bindEvents();
};

AdDemoScreen.prototype.bindEvents = function () {
	Ti.API.info('binding events');
	
    Ti.App.addEventListener('AdAvailability', function(e) {
        var adConfig = JSON.parse(e.params);
        var isAvailable = Pokkt.parseBool(adConfig.extraValues['IS_AVAILABLE']);
        var isRewarded = Pokkt.parseBool(adConfig.isRewarded);

        if (vs.currentAdConfig.screenName != adConfig.screenName)
            return;

        Ti.API.info((isRewarded ? "rewarded" : "non-rewarded") + " ad for "
            + adConfig.screenName + ", is " + (isAvailable ? "available!" : "not available!"));

        vs.labelStatus.text = isAvailable ? "ad available!" : "no ads available";

        if (rewardedAdShowRequested && Pokkt.parseBool(adConfig.isRewarded)) {
            Pokkt.showAd(CurrentPokktConfig);
            rewardedAdShowRequested = false;
        }
    });
    
    Ti.App.addEventListener('AdCachingCompleted', function(e) {
        var adConfig = JSON.parse(e.params);
        var vc = adConfig.extraValues['AD_VC'];
        var isRewarded = Pokkt.parseBool(adConfig.isRewarded);

        Ti.API.info((isRewarded ? 'rewarded' : 'non-rewarded') + ' ad is cached for '
            + adConfig.screenName + ', associated vc is ' + vc);

        if (vs.currentAdConfig.screenName != adConfig.screenName)
            return;
        
        vs.labelStatus.text = 'ad cached!';
        
        if (isRewarded) {
            vs.buttonCacheRewardedAd.title = 'rewarded ad is cached!';
            vs.buttonShowRewardedAd.title = 'Show Rewarded Ad (Cached)';
            vs.buttonShowRewardedAd.touchEnabled = true;
        } else {
            vs.buttonCacheNonRewardedAd.title = 'non-rewarded ad is cached!';
            vs.buttonShowNonRewardedAd.title = 'Show Non-Rewarded Ad (Cached)';
            vs.buttonShowNonRewardedAd.touchEnabled = true;
        }
    });
    
    Ti.App.addEventListener('AdCachingFailed', function(e) {
        var adConfig = JSON.parse(e.params);
        var message = adConfig.extraValues['MESSAGE'];
        var isRewarded = Pokkt.parseBool(adConfig.isRewarded);

        Ti.API.info((isRewarded ? "rewarded" : "non-rewarded") + " ad caching failed for "
            + adConfig.screenName + "! message: " + message);

        if (vs.currentAdConfig.screenName != adConfig.screenName)
            return;

        vs.labelStatus.text = "ad caching failed!";

        if (isRewarded) {
            vs.buttonCacheRewardedAd.title = 'Cache Rewarded Ad';
            vs.buttonShowRewardedAd.title = 'Show Rewarded Ad';
            vs.buttonCacheRewardedAd.touchEnabled = true;
            vs.buttonShowRewardedAd.touchEnabled = true;
        } else {
            vs.buttonCacheNonRewardedAd.title = 'Cache Non-Rewarded Ad';
            vs.buttonShowNonRewardedAd.title = 'Show Non-Rewarded Ad';
            vs.buttonCacheNonRewardedAd.touchEnabled = true;
            vs.buttonShowNonRewardedAd.touchEnabled = true;
        }
    });
    
    Ti.App.addEventListener('AdDisplayed', function(e) {
        var adConfig = JSON.parse(e.params);
        var isRewarded = Pokkt.parseBool(adConfig.isRewarded);

        if (vs.currentAdConfig.screenName != adConfig.screenName)
            return;

        Ti.API.info((isRewarded ? "rewarded" : "non-rewarded") + " ad is displayed for " + adConfig.screenName + "!");

        vs.labelStatus.text = "ad displayed!";

        if (isRewarded) {
            vs.buttonCacheRewardedAd.touchEnabled = false;
            vs.buttonShowRewardedAd.touchEnabled = false;
        } else {
            vs.buttonCacheNonRewardedAd.touchEnabled = false;
            vs.buttonShowNonRewardedAd.touchEnabled = false;
        }
    });
    
    Ti.App.addEventListener('AdSkipped', function(e) {
        var adConfig = JSON.parse(e.params);
        var isRewarded = Pokkt.parseBool(adConfig.isRewarded);

        if (vs.currentAdConfig.screenName != adConfig.screenName)
            return;

        Ti.API.info((isRewarded ? "rewarded" : "non-rewarded") + " ad is skipped for " + adConfig.screenName + "!");

        vs.labelStatus.text = "ad skipped!";
    });
    
    Ti.App.addEventListener('AdCompleted', function(e) {
        var adConfig = JSON.parse(e.params);
        var isRewarded = Pokkt.parseBool(adConfig.isRewarded);

        if (vs.currentAdConfig.screenName != adConfig.screenName)
            return;

        Ti.API.info((isRewarded ? "rewarded" : "non-rewarded") + " ad is completed for " + adConfig.screenName + "!");

        vs.labelStatus.text = "ad completed!";
    });
    
    Ti.App.addEventListener('AdClosed', function(e) {
        var adConfig = JSON.parse(e.params);
        var backPressed = Pokkt.parseBool(adConfig.extraValues['BACK_BUTTON']);
        var isRewarded = Pokkt.parseBool(adConfig.isRewarded);

        if (vs.currentAdConfig.screenName != adConfig.screenName)
            return;

        Ti.API.info((isRewarded ? "rewarded" : "non-rewarded") + " ad is closed for " + adConfig.screenName + "!");

        if (isRewarded) {
            vs.buttonCacheRewardedAd.title = 'Cache Rewarded Ad';
            vs.buttonShowRewardedAd.title = 'Show Rewarded Ad';
            vs.buttonCacheRewardedAd.touchEnabled = true;
            vs.buttonShowRewardedAd.touchEnabled = true;
        } else {
            vs.buttonCacheNonRewardedAd.title = 'Cache Non-Rewarded Ad';
            vs.buttonShowNonRewardedAd.title = 'Show Non-Rewarded Ad';
            vs.buttonCacheNonRewardedAd.touchEnabled = true;
            vs.buttonShowNonRewardedAd.touchEnabled = true;
        }
    });
    
    Ti.App.addEventListener('AdGratified', function(e) {
        var adConfig = JSON.parse(e.params);
        var reward = parseFloat(adConfig.extraValues['REWARD']);
        var isRewarded = Pokkt.parseBool(adConfig.isRewarded);

        if (vs.currentAdConfig.screenName != adConfig.screenName)
            return;

        Ti.API.info("ad for " + adConfig.screenName + " is gratified! reward received: " + reward);
        
        vs.totalPointsEarned += reward;
 		vs.labelPointsEarned.text = 'Points Earned: ' + vs.totalPointsEarned;
	});
};

AdDemoScreen.prototype.open = function () {
	this.rootWindow.open();
};

module.exports = AdDemoScreen;